@@ -57,10 +57,9 @@
 #include "img_viewer.h"
 
 
-#ifdef SPELLCHECK_ENABLE
+//#ifdef SPELLCHECK_ENABLE
 #include "spellchecker.h"
-#endif
-
+//#endif
 
 
 
@@ -102,7 +101,6 @@ public:
 #endif
 
 
-
 #ifdef USE_QML_STUFF
 class CQQuickWindow: public QQuickWindow
 {
@@ -112,7 +110,7 @@ public:
 
   QString id;
  
-  CQQuickWindow (QWindow * parent = 0): QQuickWindow (parent) {}
+  CQQuickWindow (QWindow *parent = 0): QQuickWindow (parent) {}
   ~CQQuickWindow() {}
  
 protected:
@@ -120,10 +118,7 @@ protected:
   bool event (QEvent *event);
 };
 
-#endif
 
-
-#ifdef USE_QML_STUFF
 class CPluginListItem: public QObject
 {
 Q_OBJECT
@@ -197,7 +192,6 @@ public slots:
 };
 
 
-
 class CAboutWindow: public QWidget
 {
 Q_OBJECT
@@ -269,14 +263,13 @@ public:
   CFMan *fman;
   CImgViewer *img_viewer;
 
-#ifdef SPELLCHECK_ENABLE
+//#ifdef SPELLCHECK_ENABLE
 
-  ASpellchecker *spellchecker;
+  CSpellchecker *spellchecker;
   QStringList spellcheckers;
   QString cur_spellchecker;
 
-#endif
-
+//#endif
 
   
   int icon_size;
@@ -314,9 +307,7 @@ public:
 
  
 #ifdef PRINTER_ENABLE
-
   QPrinter printer;
-
 #endif
 
 
@@ -372,14 +363,18 @@ public:
   QLineEdit *ed_aspellcheck_path;
   
   QCheckBox *cb_use_qregexpsyntaxhl;
-#if defined(Q_OS_LINUX) || defined(Q_WS_X11)
+
+//#if !defined(Q_OS_FREEBSD) && !defined(Q_OS_FREEBSD) && !defined(Q_OS_FREEBSD)
+//#if defined(Q_OS_LINUX) || defined(Q_WS_X11)
+#if defined(JOYSTICK_SUPPORTED)
+
   QCheckBox *cb_use_joystick;
+//#endif
 #endif
 
   QCheckBox *cb_right_to_left;
 
   QCheckBox *cb_wordwrap;
-//  QCheckBox *cb_colored_console;
   
   QCheckBox *cb_fif_at_toolbar;
   QCheckBox *cb_show_linenums;
@@ -416,15 +411,11 @@ public:
   QCheckBox *cb_output_image_flt;
 
   QComboBox *cmb_tea_icons;
-  
-  
-  QComboBox *cmb_ui_langs;
+//  QComboBox *cmb_ui_langs;
 
   QSpinBox *spb_img_quality;
   QCheckBox *cb_zip_after_scale;
-  
   QCheckBox *cb_exif_rotate;
-  
   QCheckBox *cb_zor_use_exif;
 
 
@@ -447,12 +438,10 @@ main window callbacks
   void repeat();
 
   void receiveMessage (const QString &msg);
-  
   void receiveMessageShared (const QStringList& msg);
         
   void view_use_theme();
 
-
   void select_label();
   void update_labels_menu();
   void update_labels_list();
@@ -466,8 +455,6 @@ main window callbacks
 
   void fman_unpack_zip();
   void fman_zip_info();
- // void fman_pack_sel_dir();
-
 
   void fman_refresh();
   void fman_rename();
@@ -679,7 +666,7 @@ main window callbacks
   
   void remove_formatting();
   
-#ifdef SPELLCHECK_ENABLE
+#if defined (HUNSPELL_ENABLE) || defined (ASPELL_ENABLE)
 
   void fn_change_spell_lang();
   void fn_spell_check();
@@ -693,16 +680,13 @@ main window callbacks
   void pb_choose_hunspell_path_clicked();
 #endif
 
-
 #ifdef ASPELL_ENABLE
-
 #if defined(Q_OS_WIN) || defined (Q_OS_OS2)
   void pb_choose_aspell_path_clicked();
 #endif
-
 #endif
 
-#endif
+#endif // SPELLCHECKERS ENABLED 
 
   void scale_image();
 
@@ -813,8 +797,12 @@ main window callbacks
 /*************************
 prefs window callbacks
 *************************/
-#if defined(Q_OS_LINUX) || defined(Q_WS_X11)
+//#if !defined(Q_OS_FREEBSD) && !defined(Q_OS_FREEBSD) && !defined(Q_OS_FREEBSD)
+
+//#if defined(Q_OS_LINUX) || defined(Q_WS_X11)
+#if defined(JOYSTICK_SUPPORTED)
   void cb_use_joystick_stateChanged (int state);
+//#endif
 #endif
 
 //  void cmb_ui_langs_currentIndexChanged (const QString &text);
@@ -860,7 +848,7 @@ main window widgets
   QTabWidget *main_tab_widget;
   QTabWidget *tab_options;
   QTabWidget *tab_browser;
-  QTabWidget *tab_widget;
+  QTabWidget *tab_editor;
   QLineEdit *fif;
 
   QMenu *fileMenu;
@@ -1041,7 +1029,8 @@ prefs window widgets
   void calendar_update();
 
 
-#ifdef SPELLCHECK_ENABLE
+//#ifdef SPELLCHECK_ENABLE
+#if defined (HUNSPELL_ENABLE) || defined (ASPELL_ENABLE)
   void setup_spellcheckers();
   void create_spellcheck_menu();
 #endif
